@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
-our $DATE = '2016-02-06'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-12-02'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,8 +45,7 @@ $SPEC{gen_perinci_cmdline_completer_script} = {
         },
         url => {
             summary => 'URL to function (or package, if you have subcommands)',
-            schema => 'str*',
-            'x.schema.entity' => 'riap_url',
+            schema => 'riap::url*',
             req => 1,
             pos => 1,
             tags => ['category:pericmd-attribute'],
@@ -290,7 +289,7 @@ sub gen_perinci_cmdline_completer_script {
             "# get words\n",
             'my $shell;', "\n",
             'my ($words, $cword);', "\n",
-            'if ($ENV{COMP_LINE}) { $shell = "bash"; require Complete::Bash; ($words,$cword) = @{ Complete::Bash::parse_cmdline() }; ($words,$cword) = @{ Complete::Bash::join_wordbreak_words($words,$cword) }; }', "\n",
+            'if ($ENV{COMP_LINE}) { $shell = "bash"; require Complete::Bash; require Encode; ($words,$cword) = @{ Complete::Bash::parse_cmdline() }; ($words,$cword) = @{ Complete::Bash::join_wordbreak_words($words,$cword) }; $words = [map {Encode::decode("UTF-8", $_)} @$words]; }', "\n",
             'elsif ($ENV{COMMAND_LINE}) { $shell = "tcsh"; require Complete::Tcsh; ($words,$cword) = @{ Complete::Tcsh::parse_cmdline() }; }', "\n",
             '@ARGV = @$words;', "\n",
             "\n",
@@ -301,7 +300,7 @@ sub gen_perinci_cmdline_completer_script {
             "# parse common_opts which potentially sets subcommand\n",
             '{', "\n",
             "    require Getopt::Long;\n",
-            q(    my $old_go_conf = Getopt::Long::Configure('pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev');), "\n",
+            q(    my $old_go_conf = Getopt::Long::Configure('pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev', 'no_getopt_compat', 'gnu_compat');), "\n",
             q(    my @go_spec;), "\n",
             q(    for my $k (keys %$copts) { push @go_spec, $copts->{$k}{getopt} => sub { my ($go, $val) = @_; $copts->{$k}{handler}->($go, $val, $r); } }), "\n",
             q(    Getopt::Long::GetOptions(@go_spec);), "\n",
@@ -450,7 +449,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.08 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-02-06.
+This document describes version 0.09 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-12-02.
 
 =head1 FUNCTIONS
 
@@ -540,7 +539,7 @@ then the subcommands become:
  bar => /My/App/bar
  "baz-qux" => /My/App/baz_qux
 
-=item * B<url>* => I<str>
+=item * B<url>* => I<riap::url>
 
 URL to function (or package, if you have subcommands).
 
